/**********************************************************************/
/*   This program is developed by Microsoft C 5.1                      */
/***********************************************************************/
/*   Demo 19: A/D Calibration:                                         */
/*    step 1: apply 0V to channel 0.                                   */
/*    step 2: apply  4.9998V to channel 1.                             */
/*    step 3: apply +0.6245V to channel 2.                             */
/*    step 4: adjust VR3 until CAL:0 = 0000H or FFFFH.                 */
/*    step 5: adjust VR2 until CAL:1 = 7FFFH or 7FFEH.                 */
/*    step 6: repeat step 4 and step 5 until all OK.                   */
/*    step 7: adjust VR1 until CAL:3 = 0FFCH or 0FFDH.                 */
/***********************************************************************/
#define  MYLIB
#include "P1602.H"

int main()
{
   int     i,j;
   DWORD   dwCount=0;
   WORD    wBoards,wRetVal;
   WORD    wDIOdata,wData;
   float   fVal;
   WORD    wAddrTimer,wAddrCtrl,wAddrDio,wAddrAdda;

   _clearscreen(0);
   gotoxy(1,1);

   /* initiaing P1602 card and detect how many P1602 card in PC */
   wRetVal=P1602_DriverInit(&wBoards);
   printf("Threr are %d P1602 Cards in this PC\n",wBoards);

   if( wBoards==0 )
   {
      putch(0x07);  putch(0x07);  putch(0x07);
      printf("There are no P1602 card in this PC !!!\n");
      exit(0);
   }

   /* dump every P1602 card's configuration address space */
   printf("The Configuration Space ->   Timer   Control   DIO    AD/DA\n");
   for(i=0; i<wBoards; i++)
   {
      P1602_GetConfigAddressSpace(i,&wAddrTimer,&wAddrCtrl,&wAddrDio,&wAddrAdda);
      printf("Card %02d:  Timer:%04xH  Ctrl:%04xH  Dio:%04xH  Adda:%04xH\n",
                                     i,wAddrTimer,wAddrCtrl,wAddrDio,wAddrAdda);
   }
   /*
      The P1602_ActiveBoard() function must be used to active a board,
      then all operation will take effect to the actived board.
   */
   printf("--------------------------------------------------\n");
   printf("Now Active First P1602 Card...\n");
   P1602_ActiveBoard( 0 );

   clrscr();  /* a clear screen function in P1602MC?.LIB */
   gotoxy(1,1);

   printf("A/D Calibration Program:\n");
   printf("step 1: apply 0V to channel 0.\n");
   printf("step 2: apply  4.9998V to channel 1.\n");
   printf("step 3: apply +0.6245V to channel 2.\n");
   printf("step 4: adjust VR3 until CAL:0 = 0000H or FFFFH.\n");
   printf("step 5: adjust VR2 until CAL:1 = 7FFFH or 7FFEH.\n");
   printf("step 6: repeat step 4 and step 5 until all OK.\n");
   printf("step 7: adjust VR1 until CAL:3 = OFFCH or OFFDH.\n");


   for( ; ; )
   {
      gotoxy(5,11);
      printf("Count=%ld\n",dwCount++);
     
      wRetVal=P1602_SetChannelConfig(0,1);  // CH:0, ConfigCode:1 -> +/- 5V range
      wRetVal+=P1602_DelayUs(3);            // delay 3 us settling time
      wRetVal+=P1602_AdPolling(&fVal);
      if (wRetVal==0)
      {
           wData=(int)(fVal/5.0*32768.0);
           gotoxy(5,12);
           printf("CAL:0=%04xH\n",wData);
      }
      else
      {
         putch(0x07); putch(0x07); putch(0x07);
         printf("(5.0V Range) AdPolling CH:0 Error !!!\n");
         exit(0);
      }
      
      wRetVal=P1602_SetChannelConfig(1,1);  // CH:1, ConfigCode:1 -> +/- 5V range
      wRetVal+=P1602_DelayUs(3);            // delay 3 us settling time
      wRetVal+=P1602_AdPolling(&fVal);
      if (wRetVal==0)
      {
           wData=(int)(fVal/5.0*32768.0);
           gotoxy(5,13);
           printf("CAL:1=%04xH\n",wData);
      }
      else
      {
         putch(0x07); putch(0x07); putch(0x07);
         printf("(5.0V Range) AdPolling CH:0 Error !!!\n");
         exit(0);
      }
      
      wRetVal=P1602_SetChannelConfig(2,3);  /* CH:2, ConfigCode:3 -> +/- 5V range */
      wRetVal+=P1602_DelayUs(3);            /* delay 3 us settling time  */
      wRetVal+=P1602_AdPolling(&fVal);
      if (wRetVal==0)
      {
           wData=(int)(fVal/0.625*32768.0);
           gotoxy(5,14);
           printf("CAL:2=%04xH\n",wData);
      }
      else
      {
         putch(0x07); putch(0x07); putch(0x07);
         printf("(5.0V Range) AdPolling CH:0 Error !!!\n");
         exit(0);
      }

      for(i=0; i<500; i++)
         P1602_DelayUs(1000);  /* delay 500 ms just for display purpose */

      if( kbhit() )
         break;
   }

   P1602_DriverClose();
   return 0;
}

